pub trait FullDuplex<Word: Copy = u8>: ErrorType {
// Required methods
fn read(&mut self) -> Result<Word, Self::Error>;
fn write(&mut self, word: Word) -> Result<(), Self::Error>;
}Expand description
Full duplex SPI (master mode).
Notes
-
It’s the task of the user of this interface to manage the slave select lines.
-
Due to how full duplex SPI works each
readcall must be preceded by awritecall. -
readcalls only return the data received with the lastwritecall. Previously received data is discarded -
Data is only guaranteed to be clocked out when the
readcall succeeds. The slave select line shouldn’t be released before that. -
Some SPIs can work with 8-bit and 16-bit words. You can overload this trait with different
Wordtypes to allow operation in both modes.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".